@@ -18,10 +18,13 @@
 #include <QString>
 
 #include "marble_export.h"
-#include "MarbleColors.h"
 
 // #define QT_STRICT_ITERATORS
 
+/* M_PI is a #define that may or may not be handled in <cmath> */
+#ifndef M_PI
+#define M_PI 3.14159265358979323846264338327950288419717
+#endif
 
 namespace Marble
 {
@@ -52,16 +55,6 @@ enum Projection {
     // value above. Adjust that method if you do changes here
 };
 
-/**
- * @brief This enum is used to choose the dimension.
- */
-enum Dimension {
-    Latitude,             ///< Latitude
-    Longitude            ///< Longitude
-};
-
-Q_DECLARE_FLAGS(Dimensions, Dimension)
-
 /**
  * @brief This enum is used to choose the unit chosen to measure angles.
  */
@@ -245,6 +238,8 @@ const qreal SEC2MIN = 1.0 / MIN2SEC;
 const qreal HOUR2SEC = 3600.0;
 const qreal SEC2HOUR = 1.0 / HOUR2SEC;
 
+const qreal TWOPI = 2 * M_PI;
+
 // Version definitions to use with an external application (as digiKam)
 
 // String for about dialog and http user agent
