@@ -9,51 +9,46 @@
 //
 
 #include "GeoDataScreenOverlay.h"
+#include "GeoDataScreenOverlay_p.h"
 #include "GeoDataTypes.h"
 
 namespace Marble {
 
-class GeoDataScreenOverlayPrivate
-{
-public:
-    GeoDataScreenOverlayPrivate();
-
-    GeoDataVec2  m_overlayXY;
-    GeoDataVec2  m_screenXY;
-    GeoDataVec2  m_rotationXY;
-    GeoDataVec2  m_size;
-    qreal        m_rotation;
-};
-
-GeoDataScreenOverlayPrivate::GeoDataScreenOverlayPrivate() :
-    m_rotation(0.0)
+GeoDataScreenOverlay::GeoDataScreenOverlay()
+  : GeoDataOverlay(new GeoDataScreenOverlayPrivate)
 {
 }
 
-GeoDataScreenOverlay::GeoDataScreenOverlay() :
-    d( new GeoDataScreenOverlayPrivate )
+GeoDataScreenOverlay::GeoDataScreenOverlay( const Marble::GeoDataScreenOverlay &other )
+  : GeoDataOverlay(other, new GeoDataScreenOverlayPrivate(*other.d_func()))
 {
 }
 
-GeoDataScreenOverlay::GeoDataScreenOverlay( const Marble::GeoDataScreenOverlay &other ) :
-    GeoDataOverlay( other ), d( new GeoDataScreenOverlayPrivate( *other.d ) )
+GeoDataScreenOverlay::~GeoDataScreenOverlay()
 {
 }
 
 GeoDataScreenOverlay &GeoDataScreenOverlay::operator=( const GeoDataScreenOverlay &other )
 {
-    *d = *other.d;
+    if (this != &other) {
+        Q_D(GeoDataScreenOverlay);
+        *d = *other.d_func();
+    }
+
     return *this;
 }
 
 bool GeoDataScreenOverlay::operator==(const GeoDataScreenOverlay& other) const
 {
+    Q_D(const GeoDataScreenOverlay);
+    const GeoDataScreenOverlayPrivate* const other_d = other.d_func();
+
     return equals(other) &&
-           d->m_overlayXY == other.d->m_overlayXY &&
-           d->m_screenXY == other.d->m_screenXY &&
-           d->m_rotationXY == other.d->m_rotationXY &&
-           d->m_size == other.d->m_size &&
-           d->m_rotation == other.d->m_rotation;
+           d->m_overlayXY == other_d->m_overlayXY &&
+           d->m_screenXY == other_d->m_screenXY &&
+           d->m_rotationXY == other_d->m_rotationXY &&
+           d->m_size == other_d->m_size &&
+           d->m_rotation == other_d->m_rotation;
 }
 
 bool GeoDataScreenOverlay::operator!=(const GeoDataScreenOverlay& other) const
@@ -61,9 +56,9 @@ bool GeoDataScreenOverlay::operator!=(const GeoDataScreenOverlay& other) const
     return !this->operator==(other);
 }
 
-GeoDataScreenOverlay::~GeoDataScreenOverlay()
+GeoDataFeature * GeoDataScreenOverlay::clone() const
 {
-    delete d;
+    return new GeoDataScreenOverlay(*this);
 }
 
 const char *GeoDataScreenOverlay::nodeType() const
@@ -73,17 +68,19 @@ const char *GeoDataScreenOverlay::nodeType() const
 
 GeoDataVec2 GeoDataScreenOverlay::overlayXY() const
 {
+    Q_D(const GeoDataScreenOverlay);
     return d->m_overlayXY;
 }
 
 void GeoDataScreenOverlay::setOverlayXY(const GeoDataVec2 &vec2)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_overlayXY = vec2;
 }
 
-void GeoDataScreenOverlay::setOverlayXY(const qreal &x, const qreal &y, const GeoDataVec2::Unit &xunit,
-                                        const GeoDataVec2::Unit &yunit)
+void GeoDataScreenOverlay::setOverlayXY(qreal x, qreal y, GeoDataVec2::Unit xunit, GeoDataVec2::Unit yunit)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_screenXY.setX(x);
     d->m_screenXY.setY(y);
     d->m_screenXY.setXunits(xunit);
@@ -92,17 +89,19 @@ void GeoDataScreenOverlay::setOverlayXY(const qreal &x, const qreal &y, const Ge
 
 GeoDataVec2 GeoDataScreenOverlay::screenXY() const
 {
+    Q_D(const GeoDataScreenOverlay);
     return d->m_screenXY;
 }
 
 void GeoDataScreenOverlay::setScreenXY(const GeoDataVec2 &vec2)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_screenXY = vec2;
 }
 
-void GeoDataScreenOverlay::setScreenXY(const qreal &x, const qreal &y, const GeoDataVec2::Unit &xunit,
-                                       const GeoDataVec2::Unit &yunit)
+void GeoDataScreenOverlay::setScreenXY(qreal x, qreal y, GeoDataVec2::Unit xunit, GeoDataVec2::Unit yunit)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_screenXY.setX(x);
     d->m_screenXY.setY(y);
     d->m_screenXY.setXunits(xunit);
@@ -111,17 +110,19 @@ void GeoDataScreenOverlay::setScreenXY(const qreal &x, const qreal &y, const Geo
 
 GeoDataVec2 GeoDataScreenOverlay::rotationXY() const
 {
+    Q_D(const GeoDataScreenOverlay);
     return d->m_rotationXY;
 }
 
 void GeoDataScreenOverlay::setRotationXY(const GeoDataVec2 &vec2)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_rotationXY = vec2;
 }
 
-void GeoDataScreenOverlay::setRotationXY(const qreal &x, const qreal &y, const GeoDataVec2::Unit &xunit,
-                                         const GeoDataVec2::Unit &yunit)
+void GeoDataScreenOverlay::setRotationXY(qreal x, qreal y, GeoDataVec2::Unit xunit, GeoDataVec2::Unit yunit)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_rotationXY.setX(x);
     d->m_rotationXY.setY(y);
     d->m_rotationXY.setXunits(xunit);
@@ -130,17 +131,19 @@ void GeoDataScreenOverlay::setRotationXY(const qreal &x, const qreal &y, const G
 
 GeoDataVec2 GeoDataScreenOverlay::size() const
 {
+    Q_D(const GeoDataScreenOverlay);
     return d->m_size;
 }
 
 void GeoDataScreenOverlay::setSize(const GeoDataVec2 &vec2)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_size = vec2;
 }
 
-void GeoDataScreenOverlay::setSize(const qreal &x, const qreal &y, const GeoDataVec2::Unit &xunit,
-                                   const GeoDataVec2::Unit &yunit)
+void GeoDataScreenOverlay::setSize(qreal x, qreal y, GeoDataVec2::Unit xunit, GeoDataVec2::Unit yunit)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_size.setX(x);
     d->m_size.setY(y);
     d->m_size.setXunits(xunit);
@@ -149,11 +152,13 @@ void GeoDataScreenOverlay::setSize(const qreal &x, const qreal &y, const GeoData
 
 qreal GeoDataScreenOverlay::rotation() const
 {
+    Q_D(const GeoDataScreenOverlay);
     return d->m_rotation;
 }
 
 void GeoDataScreenOverlay::setRotation(qreal rotation)
 {
+    Q_D(GeoDataScreenOverlay);
     d->m_rotation = rotation;
 }
 
