@@ -266,32 +266,33 @@ void AzimuthalProjectionPrivate::processTessellation( const GeoDataCoordinates &
         }
     }
 
-    const qreal altDiff = currentCoords.altitude() - previousCoords.altitude();
-
     // Create the tessellation nodes.
     GeoDataCoordinates previousTessellatedCoords = previousCoords;
     for ( int i = 1; i <= tessellatedNodes; ++i ) {
         const qreal t = (qreal)(i) / (qreal)( tessellatedNodes + 1 );
 
-        // interpolate the altitude, too
-        const qreal altitude = clampToGround ? 0 : altDiff * t + previousCoords.altitude();
+        GeoDataCoordinates currentTessellatedCoords;
 
-        qreal lon = 0.0;
-        qreal lat = 0.0;
         if ( followLatitudeCircle ) {
             // To tessellate along latitude circles use the
             // linear interpolation of the longitude.
-            lon = lonDiff * t + previousCoords.longitude();
-            lat = previousTessellatedCoords.latitude();
+            const qreal altDiff = currentCoords.altitude() - previousCoords.altitude();
+            const qreal altitude = altDiff * t + previousCoords.altitude();
+            const qreal lon = lonDiff * t + previousCoords.longitude();
+            const qreal lat = previousTessellatedCoords.latitude();
+
+            currentTessellatedCoords = GeoDataCoordinates(lon, lat, altitude);
         }
         else {
             // To tessellate along great circles use the
             // normalized linear interpolation ("NLERP") for latitude and longitude.
-            const Quaternion itpos = Quaternion::nlerp( previousCoords.quaternion(), currentCoords.quaternion(), t );
-            itpos. getSpherical( lon, lat );
+            currentTessellatedCoords = previousCoords.nlerp(currentCoords, t);
+        }
+
+        if (clampToGround) {
+            currentTessellatedCoords.setAltitude(0);
         }
 
-        const GeoDataCoordinates currentTessellatedCoords( lon, lat, altitude );
         crossHorizon( currentTessellatedCoords, polygons, viewport, allowLatePolygonCut );
         previousTessellatedCoords = currentTessellatedCoords;
     }
@@ -632,28 +633,24 @@ GeoDataCoordinates AzimuthalProjectionPrivate::doFindHorizon( const GeoDataCoord
         }
     }
 
-    qreal  lon = 0.0;
-    qreal  lat = 0.0;
-
-    qreal altDiff = currentCoords.altitude() - previousCoords.altitude();
+    GeoDataCoordinates horizonCoords;
 
     if ( followLatitudeCircle ) {
         // To tessellate along latitude circles use the
         // linear interpolation of the longitude.
-        lon = lonDiff * 0.5 + previousLongitude;
-        lat = previousLatitude;
+        const qreal altDiff = currentCoords.altitude() - previousCoords.altitude();
+        const qreal altitude = previousCoords.altitude() + 0.5 * altDiff;
+        const qreal lon = lonDiff * 0.5 + previousLongitude;
+        const qreal lat = previousLatitude;
+
+        horizonCoords = GeoDataCoordinates(lon, lat, altitude);
     }
     else {
         // To tessellate along great circles use the
         // normalized linear interpolation ("NLERP") for latitude and longitude.
-        const Quaternion itpos = Quaternion::nlerp( previousCoords.quaternion(), currentCoords.quaternion(), 0.5 );
-        itpos. getSpherical( lon, lat );
+        horizonCoords = previousCoords.nlerp(currentCoords, 0.5);
     }
 
-    qreal altitude = previousCoords.altitude() + 0.5 * altDiff;
-
-    GeoDataCoordinates horizonCoords( lon, lat, altitude );
-
     bool horizonHide = globeHidesPoint( horizonCoords, viewport );
 
     if ( horizonHide != currentHide ) {
